# DiffResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**_from** | **int** | The version number being diffed from. | [optional] 
**to** | **int** | The version number being diffed to. | [optional] 
**format** | **str** | The format the diff is being returned in (`text`, `html` or `html_simple`). | [optional] 
**diff** | **str** | The differences between two specified service versions. Returns the full config if the version configurations are identical. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


